View source: R/flash_clean_distance_events.R
| flash_clean_distance_events | R Documentation |
Cleans distance event results pulled from Flash Results html tables. Distance events are generally those with lengths of 400m or greater. Can present cleaned data in wide or long format.
flash_clean_distance_events(df, wide_format_distance = wide_format_clean)
distance_events(df, wide_format_distance = wide_format_clean)
df |
a data frame of distance event data from Flash Results |
wide_format_distance |
should df be presented in wide format (default is
|
a cleaned version of df
flash_clean_distance_events is a helper function inside
flash_parse_table
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.